@@ -178,21 +178,24 @@ crate, add it as a dependency inside [*Cargo.toml*]:
 
 ```toml
 [dependencies]
-fixed = "1.9"
+fixed = "1.10"
 ```
 
-The *fixed* crate requires rustc version 1.50.0 or later.
+The *fixed* crate requires rustc version 1.53.0 or later.
 
 ## Optional features
 
 The *fixed* crate has these optional feature:
 
- 1. `serde`, disabled by default. This provides serialization support for the
+ 1. `arbitrary`, disabled by default. This provides the generation of arbitrary
+    fixed-point numbers from raw, unstructured data. This feature requires the
+    [*arbitrary* crate].
+ 2. `serde`, disabled by default. This provides serialization support for the
     fixed-point types. This feature requires the [*serde* crate].
- 2. `std`, disabled by default. This is for features that are not possible under
+ 3. `std`, disabled by default. This is for features that are not possible under
     `no_std`: currently the implementation of the [`Error`] trait for
     [`ParseFixedError`].
- 3. `serde-str`, disabled by default. Fixed-point numbers are serialized as
+ 4. `serde-str`, disabled by default. Fixed-point numbers are serialized as
     strings showing the value when using human-readable formats. This feature
     requires the `serde` and the `std` optional features. **Warning:** numbers
     serialized when this feature is enabled cannot be deserialized when this
@@ -202,7 +205,7 @@ To enable features, you can add the dependency like this to [*Cargo.toml*]:
 
 ```toml
 [dependencies.fixed]
-version = "1.9"
+version = "1.10"
 features = ["serde"]
 ```
 
@@ -244,6 +247,7 @@ for inclusion in the work by you, as defined in the Apache License, Version 2.0,
 shall be dual licensed as above, without any additional terms or conditions.
 
 [*Cargo.toml*]: https://doc.rust-lang.org/cargo/guide/dependencies.html
+[*arbitrary* crate]: https://crates.io/crates/arbitrary
 [*cordic* crate]: https://crates.io/crates/cordic
 [*fixed* crate]: https://crates.io/crates/fixed
 [*fixed-macro* crate]: https://crates.io/crates/fixed-macro
@@ -285,7 +289,7 @@ shall be dual licensed as above, without any additional terms or conditions.
 */
 #![cfg_attr(not(feature = "std"), no_std)]
 #![warn(missing_docs)]
-#![doc(html_root_url = "https://docs.rs/fixed/~1.9")]
+#![doc(html_root_url = "https://docs.rs/fixed/~1.10")]
 #![doc(test(attr(deny(warnings))))]
 #![cfg_attr(feature = "fail-on-warnings", deny(warnings))]
 #![allow(clippy::wrong_self_convention)]
@@ -306,6 +310,8 @@ mod display;
 mod float_helper;
 mod from_str;
 mod helpers;
+#[cfg(feature = "arbitrary")]
+mod impl_arbitrary;
 mod impl_bytemuck;
 #[cfg(feature = "num-traits")]
 mod impl_num_traits;
@@ -440,7 +446,8 @@ in the range ",
             "</sup>/2<sup><i>f</i></sup>. The difference between successive
 numbers is constant throughout the range: <i>Δ</i> = 1/2<sup><i>f</i></sup>.
 
-When <i>f</i> = 0, <i>Δ</i> = 1 and the fixed-point number behaves like ",
+For <code>", $s_fixed, "\\<[U0]></code>, <i>f</i> = 0 and <i>Δ</i> = 1, and the
+fixed-point number behaves like ",
             if_signed_unsigned!($Signedness, "an", "a"),
             " [`", $s_inner, "`] with the value lying in the range ",
             if_signed_unsigned!(
@@ -450,8 +457,9 @@ When <i>f</i> = 0, <i>Δ</i> = 1 and the fixed-point number behaves like ",
             ),
             " ≤ <i>x</i> < 2<sup>",
             if_signed_unsigned!($Signedness, $s_nbits_m1, $s_nbits),
-            "</sup>. When <i>f</i> = ", $s_nbits, ",
-<i>Δ</i> = 1/2<sup>", $s_nbits, "</sup> and the value lies in the range ",
+            "</sup>. For <code>", $s_fixed, "\\<[U", $s_nbits, "]></code>,
+<i>f</i> = ", $s_nbits, " and <i>Δ</i> = 1/2<sup>", $s_nbits, "</sup>, and the
+value lies in the range ",
             if_signed_unsigned!($Signedness, "−1/2 ≤ <i>x</i> < 1/2", "0 ≤ <i>x</i> < 1"),
             ".
 
@@ -477,6 +485,8 @@ assert_eq!(two_point_75.to_string(), \"2.8\");
 ```
 
 [*typenum* crate]: https://crates.io/crates/typenum
+[U0]: crate::types::extra::U0
+[U", $s_nbits, "]: crate::types::extra::U", $s_nbits, "
 [const generics]: https://github.com/rust-lang/rust/issues/44580
 ";
             #[repr(transparent)]
